@@ -15,11 +15,17 @@ import numpyro.distributions as dist
 import numpyro.optim as optim
 from numpyro.infer import SVI, Trace_ELBO
 from numpyro.infer.autoguide import AutoDelta
-
+try:
+    from . import _version
+    version = _version.version
+except ImportError:
+    version = "dev"
 import argparse
 
 
 def main():
+    print(f"Chronumental {version}")
+    print("")
     parser = argparse.ArgumentParser(
         description=
         'Convert a distance tree into time tree with distances in days.')
